/**
    @file ft51_timer_registers.h

    @brief Timer registers library

    Registers and bit-masks for timers A, B, C and D.  These offer wider functionality
    than the standard 8051 timers 0, 1 and 2 which are controlled by SFRs.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_TIMER_REGISTERS_H__
#define __FT51_TIMER_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 112 (0x70) TIMER_CONTROL
#define TIMER_CONTROL                         0x70

// Register 112 Bit Definitions
#define BIT_TIMER_SOFT_RESET                  0                                 // Write a 1 to reset TIMER
#define MASK_TIMER_SOFT_RESET                 (0x1 << BIT_TIMER_SOFT_RESET)
#define BIT_TIMER_DEV_EN                      1                                 // Write a 1 to enable TIMER
#define MASK_TIMER_DEV_EN                     (0x1 << BIT_TIMER_DEV_EN)

//------------------------------------------------------------------------------
// Register 113 (0x71) TIMER_CONTROL_1
#define TIMER_CONTROL_1                     0x71

// Register 113 Bit Definitions
#define BIT_START_A                           0                                 // Start the timer.
#define MASK_START_A                          (0x1 << BIT_START_A)
#define BIT_START_B                           1                                 // Start the timer.
#define MASK_START_B                          (0x1 << BIT_START_B)
#define BIT_START_C                           2                                 // Start the timer.
#define MASK_START_C                          (0x1 << BIT_START_C)
#define BIT_START_D                           3                                 // Start the timer.
#define MASK_START_D                          (0x1 << BIT_START_D)
#define BIT_STOP_A                            4                                 // Stop the timer.
#define MASK_STOP_A                           (0x1 << BIT_STOP_A)
#define BIT_STOP_B                            5                                 // Stop the timer.
#define MASK_STOP_B                           (0x1 << BIT_STOP_B)
#define BIT_STOP_C                            6                                 // Stop the timer.
#define MASK_STOP_C                           (0x1 << BIT_STOP_C)
#define BIT_STOP_D                            7                                 // Stop the timer.
#define MASK_STOP_D                           (0x1 << BIT_STOP_D)

//------------------------------------------------------------------------------
// Register 114 (0x72) TIMER_CONTROL_2
#define TIMER_CONTROL_2                     0x72

// Register 114 Bit Definitions
#define BIT_START_WDG                         0                                 // Start watchdog.
#define MASK_START_WDG                        (0x1 << BIT_START_WDG)
#define BIT_CLEAR_WDG                         1                                 // Clear watchdog.
#define MASK_CLEAR_WDG                        (0x1 << BIT_CLEAR_WDG)
#define BIT_WDG_INT                           2                                 // Watchdog interrupt.
#define MASK_WDG_INT                          (0x1 << BIT_WDG_INT)
#define BIT_WDG_INT_IEN                       3                                 // Watchdog interrupt enable.
#define MASK_WDG_INT_IEN                      (0x1 << BIT_WDG_INT_IEN)
#define BIT_PRESCALER_EN_0                    4                                 // Enable prescaler bits for timers A..D.
#define MASK_PRESCALER_EN_0                   (0x1 << BIT_PRESCALER_EN_0)
#define BIT_PRESCALER_EN_1                    5                                 // Enable prescaler bits for timers A..D.
#define MASK_PRESCALER_EN_1                   (0x1 << BIT_PRESCALER_EN_1)
#define BIT_PRESCALER_EN_2                    6                                 // Enable prescaler bits for timers A..D.
#define MASK_PRESCALER_EN_2                   (0x1 << BIT_PRESCALER_EN_2)
#define BIT_PRESCALER_EN_3                    7                                 // Enable prescaler bits for timers A..D.
#define MASK_PRESCALER_EN_3                   (0x1 << BIT_PRESCALER_EN_3)
#define MASK_PRESCALER_EN                     (0xF << BIT_PRESCALER_EN_0)

//------------------------------------------------------------------------------
// Register 115 (0x73) TIMER_CONTROL_3
#define TIMER_CONTROL_3                     0x73

// Register 115 Bit Definitions
#define BIT_MODE_0                            0                                 // Write '1' to enable one-shot. Default: Continuos mode.
#define MASK_MODE_0                           (0x1 << BIT_MODE_0)
#define BIT_MODE_1                            1                                 // Write '1' to enable one-shot. Default: Continuos mode.
#define MASK_MODE_1                           (0x1 << BIT_MODE_1)
#define BIT_MODE_2                            2                                 // Write '1' to enable one-shot. Default: Continuos mode.
#define MASK_MODE_2                           (0x1 << BIT_MODE_2)
#define BIT_MODE_3                            3                                 // Write '1' to enable one-shot. Default: Continuos mode.
#define MASK_MODE_3                           (0x1 << BIT_MODE_3)
#define MASK_MODE                             (0xF << BIT_MODE_0)
#define BIT_DIRECTION_0                       4                                 // Write '1' for up counter. Default: Down counter.
#define MASK_DIRECTION_0                      (0x1 << BIT_DIRECTION_0)
#define BIT_DIRECTION_1                       5                                 // Write '1' for up counter. Default: Down counter.
#define MASK_DIRECTION_1                      (0x1 << BIT_DIRECTION_1)
#define BIT_DIRECTION_2                       6                                 // Write '1' for up counter. Default: Down counter.
#define MASK_DIRECTION_2                      (0x1 << BIT_DIRECTION_2)
#define BIT_DIRECTION_3                       7                                 // Write '1' for up counter. Default: Down counter.
#define MASK_DIRECTION_3                      (0x1 << BIT_DIRECTION_3)
#define MASK_DIRECTION                        (0xF << BIT_DIRECTION_0)

//------------------------------------------------------------------------------
// Register 116 (0x74) TIMER_CONTROL_4
#define TIMER_CONTROL_4                     0x74

// Register 116 Bit Definitions
#define BIT_CLEAR_A                           0                                 // Clear Timer A.
#define MASK_CLEAR_A                          (0x1 << BIT_CLEAR_A)
#define BIT_CLEAR_B                           1                                 // Clear Timer B.
#define MASK_CLEAR_B                          (0x1 << BIT_CLEAR_B)
#define BIT_CLEAR_C                           2                                 // Clear Timer C.
#define MASK_CLEAR_C                          (0x1 << BIT_CLEAR_C)
#define BIT_CLEAR_D                           3                                 // Clear Timer D.
#define MASK_CLEAR_D                          (0x1 << BIT_CLEAR_D)
#define BIT_PRESC_CLEAR                       4                                 // Prescaler clear.
#define MASK_PRESC_CLEAR                      (0x1 << BIT_PRESC_CLEAR)

//------------------------------------------------------------------------------
// Register 117 (0x75) TIMER_INT
#define TIMER_INT                           0x75

// Register 117 Bit Definitions
#define BIT_TIMER_INT_A                       0                                 // The timer A interrupt.
#define MASK_TIMER_INT_A                      (0x1 << BIT_TIMER_INT_A)
#define BIT_TIMER_INT_A_IEN                   1                                 // Timer interrupt enable.
#define MASK_TIMER_INT_A_IEN                  (0x1 << BIT_TIMER_INT_A_IEN)
#define BIT_TIMER_INT_B                       2                                 // The timer B interrupt.
#define MASK_TIMER_INT_B                      (0x1 << BIT_TIMER_INT_B)
#define BIT_TIMER_INT_B_IEN                   3                                 // Timer interrupt enable.
#define MASK_TIMER_INT_B_IEN                  (0x1 << BIT_TIMER_INT_B_IEN)
#define BIT_TIMER_INT_C                       4                                 // The timer C interrupt.
#define MASK_TIMER_INT_C                      (0x1 << BIT_TIMER_INT_C)
#define BIT_TIMER_INT_C_IEN                   5                                 // Timer interrupt enable.
#define MASK_TIMER_INT_C_IEN                  (0x1 << BIT_TIMER_INT_C_IEN)
#define BIT_TIMER_INT_D                       6                                 // The timer D interrupt.
#define MASK_TIMER_INT_D                      (0x1 << BIT_TIMER_INT_D)
#define BIT_TIMER_INT_D_IEN                   7                                 // Timer interrupt enable.
#define MASK_TIMER_INT_D_IEN                  (0x1 << BIT_TIMER_INT_D_IEN)

//------------------------------------------------------------------------------
// Register 118 (0x76) TIMER_SELECT
#define TIMER_SELECT                        0x76

// Register 118 Bit Definitions
#define BIT_TIMER_SEL_0                       0                                 // Timer select bits.
#define MASK_TIMER_SEL_0                      (0x1 << BIT_TIMER_SEL_0)
#define BIT_TIMER_SEL_1                       1                                 // Timer select bits.
#define MASK_TIMER_SEL_1                      (0x1 << BIT_TIMER_SEL_1)
#define MASK_TIMER_SEL                        (0x3 << BIT_TIMER_SEL_0)
#define BIT_TIMER_READ_SEL_0                  2                                 // Timer read select bits.
#define MASK_TIMER_READ_SEL_0                 (0x1 << BIT_TIMER_READ_SEL_0)
#define BIT_TIMER_READ_SEL_1                  3                                 // Timer read select bits.
#define MASK_TIMER_READ_SEL_1                 (0x1 << BIT_TIMER_READ_SEL_1)
#define MASK_TIMER_READ_SEL                   (0x3 << BIT_TIMER_READ_SEL_0)

//------------------------------------------------------------------------------
// Register 119 (0x77) TIMER_WDG
#define TIMER_WDG                           0x77

// Register 119 Bit Definitions
#define BIT_TIMER_WDG_WRITE_0                 0                                 // Watchdog bit position to initialise.
#define MASK_TIMER_WDG_WRITE_0                (0x1 << BIT_TIMER_WDG_WRITE_0)
#define BIT_TIMER_WDG_WRITE_1                 1                                 // Watchdog bit position to initialise.
#define MASK_TIMER_WDG_WRITE_1                (0x1 << BIT_TIMER_WDG_WRITE_1)
#define BIT_TIMER_WDG_WRITE_2                 2                                 // Watchdog bit position to initialise.
#define MASK_TIMER_WDG_WRITE_2                (0x1 << BIT_TIMER_WDG_WRITE_2)
#define BIT_TIMER_WDG_WRITE_3                 3                                 // Watchdog bit position to initialise.
#define MASK_TIMER_WDG_WRITE_3                (0x1 << BIT_TIMER_WDG_WRITE_3)
#define BIT_TIMER_WDG_WRITE_4                 4                                 // Watchdog bit position to initialise.
#define MASK_TIMER_WDG_WRITE_4                (0x1 << BIT_TIMER_WDG_WRITE_4)
#define MASK_TIMER_WDG_WRITE                  (0x1F << BIT_TIMER_WDG_WRITE_0)

//------------------------------------------------------------------------------
// Register 120 (0x78) TIMER_WRITE_LS
#define TIMER_WRITE_LS                      0x78

// Register 120 Bit Definitions
#define BIT_TIMER_WRITE_7_0_0                 0                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_WRITE_7_0_0                (0x1 << BIT_TIMER_WRITE_7_0_0)
#define BIT_TIMER_WRITE_7_0_1                 1                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_WRITE_7_0_1                (0x1 << BIT_TIMER_WRITE_7_0_1)
#define BIT_TIMER_WRITE_7_0_2                 2                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_WRITE_7_0_2                (0x1 << BIT_TIMER_WRITE_7_0_2)
#define BIT_TIMER_WRITE_7_0_3                 3                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_WRITE_7_0_3                (0x1 << BIT_TIMER_WRITE_7_0_3)
#define BIT_TIMER_WRITE_7_0_4                 4                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_WRITE_7_0_4                (0x1 << BIT_TIMER_WRITE_7_0_4)
#define BIT_TIMER_WRITE_7_0_5                 5                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_WRITE_7_0_5                (0x1 << BIT_TIMER_WRITE_7_0_5)
#define BIT_TIMER_WRITE_7_0_6                 6                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_WRITE_7_0_6                (0x1 << BIT_TIMER_WRITE_7_0_6)
#define BIT_TIMER_WRITE_7_0_7                 7                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_WRITE_7_0_7                (0x1 << BIT_TIMER_WRITE_7_0_7)
#define MASK_TIMER_WRITE_7_0                  (0xFF << BIT_TIMER_WRITE_7_0_0)

//------------------------------------------------------------------------------
// Register 121 (0x79) TIMER_WRITE_MS
#define TIMER_WRITE_MS                      0x79

// Register 121 Bit Definitions
#define BIT_TIMER_WRITE_15_8_0                0                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_WRITE_15_8_0               (0x1 << BIT_TIMER_WRITE_15_8_0)
#define BIT_TIMER_WRITE_15_8_1                1                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_WRITE_15_8_1               (0x1 << BIT_TIMER_WRITE_15_8_1)
#define BIT_TIMER_WRITE_15_8_2                2                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_WRITE_15_8_2               (0x1 << BIT_TIMER_WRITE_15_8_2)
#define BIT_TIMER_WRITE_15_8_3                3                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_WRITE_15_8_3               (0x1 << BIT_TIMER_WRITE_15_8_3)
#define BIT_TIMER_WRITE_15_8_4                4                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_WRITE_15_8_4               (0x1 << BIT_TIMER_WRITE_15_8_4)
#define BIT_TIMER_WRITE_15_8_5                5                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_WRITE_15_8_5               (0x1 << BIT_TIMER_WRITE_15_8_5)
#define BIT_TIMER_WRITE_15_8_6                6                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_WRITE_15_8_6               (0x1 << BIT_TIMER_WRITE_15_8_6)
#define BIT_TIMER_WRITE_15_8_7                7                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_WRITE_15_8_7               (0x1 << BIT_TIMER_WRITE_15_8_7)
#define MASK_TIMER_WRITE_15_8                 (0xFF << BIT_TIMER_WRITE_15_8_0)

//------------------------------------------------------------------------------
// Register 122 (0x7A) TIMER_PRESC_LS
#define TIMER_PRESC_LS                      0x7A

// Register 122 Bit Definitions
#define BIT_TIMER_PRESC_7_0_0                 0                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_PRESC_7_0_0                (0x1 << BIT_TIMER_PRESC_7_0_0)
#define BIT_TIMER_PRESC_7_0_1                 1                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_PRESC_7_0_1                (0x1 << BIT_TIMER_PRESC_7_0_1)
#define BIT_TIMER_PRESC_7_0_2                 2                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_PRESC_7_0_2                (0x1 << BIT_TIMER_PRESC_7_0_2)
#define BIT_TIMER_PRESC_7_0_3                 3                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_PRESC_7_0_3                (0x1 << BIT_TIMER_PRESC_7_0_3)
#define BIT_TIMER_PRESC_7_0_4                 4                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_PRESC_7_0_4                (0x1 << BIT_TIMER_PRESC_7_0_4)
#define BIT_TIMER_PRESC_7_0_5                 5                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_PRESC_7_0_5                (0x1 << BIT_TIMER_PRESC_7_0_5)
#define BIT_TIMER_PRESC_7_0_6                 6                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_PRESC_7_0_6                (0x1 << BIT_TIMER_PRESC_7_0_6)
#define BIT_TIMER_PRESC_7_0_7                 7                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_PRESC_7_0_7                (0x1 << BIT_TIMER_PRESC_7_0_7)
#define MASK_TIMER_PRESC_7_0                  (0xFF << BIT_TIMER_PRESC_7_0_0)

//------------------------------------------------------------------------------
// Register 123 (0x7B) TIMER_PRESC_MS
#define TIMER_PRESC_MS                      0x7B

// Register 123 Bit Definitions
#define BIT_TIMER_PRESC_15_8_0                0                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_PRESC_15_8_0               (0x1 << BIT_TIMER_PRESC_15_8_0)
#define BIT_TIMER_PRESC_15_8_1                1                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_PRESC_15_8_1               (0x1 << BIT_TIMER_PRESC_15_8_1)
#define BIT_TIMER_PRESC_15_8_2                2                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_PRESC_15_8_2               (0x1 << BIT_TIMER_PRESC_15_8_2)
#define BIT_TIMER_PRESC_15_8_3                3                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_PRESC_15_8_3               (0x1 << BIT_TIMER_PRESC_15_8_3)
#define BIT_TIMER_PRESC_15_8_4                4                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_PRESC_15_8_4               (0x1 << BIT_TIMER_PRESC_15_8_4)
#define BIT_TIMER_PRESC_15_8_5                5                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_PRESC_15_8_5               (0x1 << BIT_TIMER_PRESC_15_8_5)
#define BIT_TIMER_PRESC_15_8_6                6                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_PRESC_15_8_6               (0x1 << BIT_TIMER_PRESC_15_8_6)
#define BIT_TIMER_PRESC_15_8_7                7                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_PRESC_15_8_7               (0x1 << BIT_TIMER_PRESC_15_8_7)
#define MASK_TIMER_PRESC_15_8                 (0xFF << BIT_TIMER_PRESC_15_8_0)

//------------------------------------------------------------------------------
// Register 124 (0x7C) TIMER_READ_LS
#define TIMER_READ_LS                       0x7C

// Register 124 Bit Definitions
#define BIT_TIMER_READ_7_0_0                  0                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_READ_7_0_0                 (0x1 << BIT_TIMER_READ_7_0_0)
#define BIT_TIMER_READ_7_0_1                  1                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_READ_7_0_1                 (0x1 << BIT_TIMER_READ_7_0_1)
#define BIT_TIMER_READ_7_0_2                  2                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_READ_7_0_2                 (0x1 << BIT_TIMER_READ_7_0_2)
#define BIT_TIMER_READ_7_0_3                  3                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_READ_7_0_3                 (0x1 << BIT_TIMER_READ_7_0_3)
#define BIT_TIMER_READ_7_0_4                  4                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_READ_7_0_4                 (0x1 << BIT_TIMER_READ_7_0_4)
#define BIT_TIMER_READ_7_0_5                  5                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_READ_7_0_5                 (0x1 << BIT_TIMER_READ_7_0_5)
#define BIT_TIMER_READ_7_0_6                  6                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_READ_7_0_6                 (0x1 << BIT_TIMER_READ_7_0_6)
#define BIT_TIMER_READ_7_0_7                  7                                 // Bits 7 to 0 of the timer start value.
#define MASK_TIMER_READ_7_0_7                 (0x1 << BIT_TIMER_READ_7_0_7)
#define MASK_TIMER_READ_7_0                   (0xFF << BIT_TIMER_READ_7_0_0)

//------------------------------------------------------------------------------
// Register 125 (0x7D) TIMER_READ_MS
#define TIMER_READ_MS                       0x7D

// Register 125 Bit Definitions
#define BIT_TIMER_READ_15_8_0                 0                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_READ_15_8_0                (0x1 << BIT_TIMER_READ_15_8_0)
#define BIT_TIMER_READ_15_8_1                 1                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_READ_15_8_1                (0x1 << BIT_TIMER_READ_15_8_1)
#define BIT_TIMER_READ_15_8_2                 2                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_READ_15_8_2                (0x1 << BIT_TIMER_READ_15_8_2)
#define BIT_TIMER_READ_15_8_3                 3                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_READ_15_8_3                (0x1 << BIT_TIMER_READ_15_8_3)
#define BIT_TIMER_READ_15_8_4                 4                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_READ_15_8_4                (0x1 << BIT_TIMER_READ_15_8_4)
#define BIT_TIMER_READ_15_8_5                 5                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_READ_15_8_5                (0x1 << BIT_TIMER_READ_15_8_5)
#define BIT_TIMER_READ_15_8_6                 6                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_READ_15_8_6                (0x1 << BIT_TIMER_READ_15_8_6)
#define BIT_TIMER_READ_15_8_7                 7                                 // Bits 15 to 8 of the timer start value.
#define MASK_TIMER_READ_15_8_7                (0x1 << BIT_TIMER_READ_15_8_7)
#define MASK_TIMER_READ_15_8                  (0xFF << BIT_TIMER_READ_15_8_0)

#endif // __FT51_TIMER_REGISTERS_H__